%%%%%%%%%%%%%%%%%% SIMULATION OF 6-PUS PARALLEL MANIPULATORS %%%%%%%%%%%%%%%%%%%
%                                                                              %
%  References: (1) Bonev, I. A., and Ryu, J., "Workspace Analysis of 6-PRRS    %
%                  Parallel Manipulators Based on the Vertex Space Concept",   %
%                  ASME Design Engineering Technical Conferences (DETC'99),    %
%                  Las Vegas, NV, September 12-15, 1999.                       %
%                  (http://wwwrobot.gmc.ulaval.ca/~bonev/DAC_8647.pdf)         %
%                                                                              %
% Created by: Ilian Bonev                e-mail: bonev@parallemic.org          %
% Last modified: July 20, 2000                                                 %
%                                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% GRAPHICS INITIALIZATION-------------------------------------------------------
 clear all;
 fig = figure('Name', '6-PUS PM Simulation', 'NumberTitle', 'off',...
              'Position', [7,60,850,600]);
 set(gca, 'drawmode', 'fast');
 set(fig, 'MenuBar', 'none', 'BackingStore', 'off');
 subplot('Position', [0.08,0.1,0.6,0.85]);
 view([1,1.5,1]); rotate3d;
 axis([-1000 1000 -1000 1000 -1400 250]); grid; axis equal;

% DEFINITION OF MANIPULATOR GEOMETRY--------------------------------------------
 l = 900;  % length of legs
 ls = l^2;
 lambdamax = 700;  % actuator stroke

% DEFINITION OF PLATFORM--------------------------------------------------------
 plat = line('color',[.5,0,0],'erasemode','xor','LineWidth',1.3);
 Bp = [  -51.507, -161.507, -110.000, 110.000, 161.507,   51.507; ...
        -156.755,   33.771,  122.984, 122.984,  33.771, -156.755; ...
         200.000,  200.000,  200.000, 200.000, 200.000,  200.000];
 B = Bp;  % platform initial position
 for i= 1:6, B(3,i)=-1230.461; end;
 set(plat,'xdata',[B(1,:),B(1,1)],'ydata',[B(2,:),B(2,1)],'zdata', ...
	  [B(3,:),B(3,1)]);

% DEFINITION OF TOOL------------------------------------------------------------
 tool=line('color',[.5,0,0],'erasemode','xor','LineWidth',1.3);
 tooltip=line('color',[0,0,0.3],'Marker','o','MarkerSize',1,'erasemode','none');
 C0p = [0.000; 0.000; 200.000];
 C = [0.000; 0.000; -1430.461]; C0 = [0; 0; -1230.461];
 set(tool,'xdata',[C0(1),C(1)],'ydata',[C0(2),C(2)],'zdata',[C0(3),C(3)]);
 set(tooltip,'xdata',[C(1),C(1)],'ydata',[C(2),C(2)],'zdata',[C(3),C(3)]);
        
% DRAWING OF BASE---------------------------------------------------------------
 base1=line('color',[0,0,0.5],'erasemode','none','LineWidth',1.5);
 base2=line('color',[0,0,0.5],'erasemode','none','LineWidth',1.5);
 base3=line('color',[0,0,0.5],'erasemode','none','LineWidth',1.5);
 base4=line('color',[0,0,0.5],'erasemode','none','LineWidth',1.5);
 base5=line('color',[0,0,0.5],'erasemode','none','LineWidth',1.5);
 base6=line('color',[0,0,0.5],'erasemode','none','LineWidth',1.5);
 A0 = [  -834.1059, -944.1059, -110.0000,  110.0000,  854.5302,  744.5302; ...
         -608.5883, -418.0628, 1026.6511, 1026.6511, -418.0628, -608.5883; ...
            0.0000,    0.0000,    0.0000,    0.0000,    0.0000,    0.0000];
 A1 = [  -227.8882, -337.8882, -110.0000,  110.0000,  329.5302,  219.5302; ...
         -258.5883,  -68.0628,  326.6511,  326.6511,  -68.0628, -258.5883; ...
         -350.0000, -350.0000, -350.0000, -350.0000, -350.0000, -350.0000];
 a = (A1-A0)/lambdamax;  % matrix of unit vectors along sliders
 A = A1;  % base joints initial position
 set(base1,'xdata',[A1(1,1);A0(1,1)],'ydata',[A1(2,1);A0(2,1)], ...
           'zdata',[A1(3,1);A0(3,1)]);
 set(base2,'xdata',[A1(1,2);A0(1,2)],'ydata',[A1(2,2);A0(2,2)], ...
           'zdata',[A1(3,2);A0(3,2)]);
 set(base3,'xdata',[A1(1,3);A0(1,3)],'ydata',[A1(2,3);A0(2,3)], ...
           'zdata',[A1(3,3);A0(3,3)]);
 set(base4,'xdata',[A1(1,4);A0(1,4)],'ydata',[A1(2,4);A0(2,4)], ...
           'zdata',[A1(3,4);A0(3,4)]);
 set(base5,'xdata',[A1(1,5);A0(1,5)],'ydata',[A1(2,5);A0(2,5)], ...
           'zdata',[A1(3,5);A0(3,5)]);
 set(base6,'xdata',[A1(1,6);A0(1,6)],'ydata',[A1(2,6);A0(2,6)], ...
           'zdata',[A1(3,6);A0(3,6)]);

% DEFINITION OF LEGS------------------------------------------------------------
 leg1=line('color',[0,0.3,0],'LineStyle','-','erasemode','xor','LineWidth',1.5);
 leg2=line('color',[0,0.3,0],'LineStyle','-','erasemode','xor','LineWidth',1.5);
 leg3=line('color',[0,0.3,0],'LineStyle','-','erasemode','xor','LineWidth',1.5);
 leg4=line('color',[0,0.3,0],'LineStyle','-','erasemode','xor','LineWidth',1.5);
 leg5=line('color',[0,0.3,0],'LineStyle','-','erasemode','xor','LineWidth',1.5);
 leg6=line('color',[0,0.3,0],'LineStyle','-','erasemode','xor','LineWidth',1.5);
 set(leg1,'xdata',[A(1,1);B(1,1)],'ydata',[A(2,1);B(2,1)], ...
	  'zdata',[A(3,1);B(3,1)]);
 set(leg2,'xdata',[A(1,2);B(1,2)],'ydata',[A(2,2);B(2,2)], ...
          'zdata',[A(3,2);B(3,2)]);
 set(leg3,'xdata',[A(1,3);B(1,3)],'ydata',[A(2,3);B(2,3)], ...
          'zdata',[A(3,3);B(3,3)]);
 set(leg4,'xdata',[A(1,4);B(1,4)],'ydata',[A(2,4);B(2,4)], ...
          'zdata',[A(3,4);B(3,4)]);
 set(leg5,'xdata',[A(1,5);B(1,5)],'ydata',[A(2,5);B(2,5)], ...
          'zdata',[A(3,5);B(3,5)]);
 set(leg6,'xdata',[A(1,6);B(1,6)],'ydata',[A(2,6);B(2,6)], ...
          'zdata',[A(3,6);B(3,6)]);

% DEFINITION OF BASE COORDINATE SYSTEM -----------------------------------------
 X_axis=line('color','k','erasemode','none','LineWidth',1.5);
 Y_axis=line('color','k','erasemode','none','LineWidth',1.5);
 Z_axis=line('color','k','erasemode','none','LineWidth',1.5);
 set(X_axis,'xdata',[0;200],'ydata',[0;0],'zdata',[0;0]);
 set(Y_axis,'xdata',[0;0],'ydata',[0;200],'zdata',[0;0]);
 set(Z_axis,'xdata',[0;0],'ydata',[0;0],'zdata',[0;200]);
 text(300,0,0,'X'); text(0,250,0,'Y'); text(0,50,200,'Z');
 text(A0(1,1),A0(2,1),40,'1'); text(A0(1,2),A0(2,2),40,'2');
 text(A0(1,3),A0(2,3),40,'3'); text(A0(1,4),A0(2,4),40,'4');
 text(A0(1,5),A0(2,5),40,'5'); text(A0(1,6),A0(2,6),40,'6');

 PUS_GUI;  % runs the GUI interface
