%%%%%%%%%%%%%%%%%%% CIRCULAR MOTION WITH CONSTANT TILT ANGLE %%%%%%%%%%%%%%%%%%%
%                                                                              %
% Created by: Ilian Bonev                e-mail: bonev@parallemic.org          %
% Last modified: July 20, 2000                                                 %
%                                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% TRAJECTORY PARAMETERS---------------------------------------------------------
 tilt_angle = pi/6;
 altitude = -1000;  % altitude at which the tool tip describes a circle
 radius_circle = 200;  % radius of circle
 s1 = 10; s2 = 30; s3 = 100; s4 = s2; s5 = s1;  % substeps
 num_steps = s1 + s2 + s3 + s4 + s5;  % number of defined trajectory points

% Z-MOTION----------------------------------------------------------------------
 for i = 1:s1;
  C(:,i) = [0.000; 0.000; -660 - 10*i];
  R(:,:,i) = RotMat(0, 0, 0);
 end;

% ZX-MOTION (To Go To The Circle Initial Point) + TILT ANGLE CHANGE-------------
 for i = (s1+1):(s1+s2);
  C(:,i) = [ 0.000 + radius_circle*(i-s1)/s2; 0.000; ...
            C(3,s1) + (altitude-C(3,s1))*(i-s1)/s2];
  theta = - tilt_angle*(i-s1)/s2;
  R(:,:,i) = RotMat(0, theta, 0);
 end;

% CIRCULAR MOTION WITH CONSTANT TILT ANGLE--------------------------------------
 for i = (s1+s2+1):(s1+s2+s3);
  C(:,i) = [radius_circle*cos(2*pi*(i-s2-s1)/s3); ...
            radius_circle*sin(2*pi*(i-s2-s1)/s3); altitude];
  phi = 0 + (i-s1-s2)*2*pi/s3;
  R(:,:,i) = RotMat(phi, theta, 0);
 end;

% RETURN MOTION-----------------------------------------------------------------
 for i = (s1+s2+s3+1):(s1+s2+s3+s4);
  C(:,i) = [radius_circle - radius_circle*(i-s1-s2-s3)/s4; 0.000; ...
            altitude - (altitude-C(3,s1))*(i-s1-s2-s3)/s4];
  theta = -tilt_angle + (tilt_angle/s4)*(i-s1-s2-s3);
  R(:,:,i) = RotMat(0, theta, 0);
 end;

% RETURN MOTION-----------------------------------------------------------------
 for i = (s1+s2+s3+s4+1):num_steps;
  C(:,i) = [0.000; 0.000; C(3,s1) + 10*(i-s1-s2-s3-s4)];
  R(:,:,i) = RotMat(0, 0, 0);
 end;
